@@ -7,22 +7,12 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03'; # TRIAL
+our $VERSION = '0.04'; # TRIAL
 
 use overload ();
 use Carp;
 
-my %OP = (
-
-    # grab 'em all
-    (
-        map +( $_ => undef ),
-        grep( $_ ne 'fallback',
-            map( split( /\s+/, $_ ), values %overload::ops ) )
-    ),
-
-    # and update those we known with a method name
-    # anything undef will trigger an error in the test suite.
+my %MethodNames = (
 
     # with_assign     	=> '+ - * / % ** << >> x .',
     '+'  		=> 'add',
@@ -130,6 +120,16 @@ my %OP = (
     '='        		=> 'copy_constructor',
 );
 
+# get those supported on this version of Perl
+my @PlatformOps = grep( $_ ne 'fallback',
+		map( split( /\s+/, $_ ), values %overload::ops ) );
+
+# and create a mapping to the method names. if a method name
+# is missing, it'll result in an undef entry in the mapping,
+# and it'll trigger an error in the test suite.
+my %OP;
+@OP{@PlatformOps} = @MethodNames{@PlatformOps};
+
 
 # operator overloads are stored in the symbol table as "($op"
 #
@@ -278,6 +278,9 @@ sub tag_to_ops {
 
     my ( $tag ) = $op =~ /^:(.*)$/;
 
+    croak( "couldn't parse \$op:  $op\n" )
+      if ! defined $tag;
+
     return grep( $_ ne 'fallback', split( /\s+/, $overload::ops{$tag} ) )
       if defined $overload::ops{$tag};
 
@@ -357,7 +360,7 @@ overload::reify - Provide named methods for inherited overloaded operators
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
